@@ -36,13 +36,17 @@ with open('$toml', 'w') as f:
 END
 }
 
+mkdir $root/archive
+
 # Build wheels for common libfranka versions
 libfranka=("0.7.1" "0.8.0" "0.9.2" "0.10.0")
 for value in "${libfranka[@]}"; do
   echo "Changing libfranka version in pyproject.toml to: $value"
   change_version "$version+libfranka-$value" "LIBFRANKA_VER=$value"
   export LIBFRANKA_VER=$value
-  python -m cibuildwheel --output-dir $root/wheelhouse $root
+  archive=panda_py_${version}_libfranka_${value}
+  python -m cibuildwheel --output-dir $root/$archive $root
+  zip -j $root/archive/$archive.zip $root/$archive/*.whl
 done
 
 # Change back to default version
